unixfont(6D)

unixfont - Convert Macintosh and IBM PC POSTSCRIPT outline fonts into Unix format.

Showing IRIX 6.5.30 (default release). Unchanged since IRIX 6.5.

NAME
     unixfont - Convert Macintosh and IBM PC POSTSCRIPT outline fonts into
     Unix format.

SYNOPSIS
     unixfont [ -d scsidevice ] [ -o outputfile ]
          [ [ -a fontname ] [ -f fontname ] [ -l typename ] [ -t textfile ]
          [ -A dosasciifile ] [ -B dosbinaryfile ]
          [ -F dosfontfile ] [ -L ]
          [ -i ibmfile ] [ -m macfile ] ] [ -v ] [ filename ... ]

DESCRIPTION
     unixfont converts POSTSCRIPT typeface programs (printer fonts) from the
     special-format files used in Adobe's Apple Macintosh and IBM PC font
     packages into the format required by Adobe's Unix-based software
     (POSTSCRIPT interpreters and the TranScript product).  The typeface must
     be licensed for use with the POSTSCRIPT interpreter to which it is to be
     made available from the Unix system.  unixfont can also extract typeface
     programs and Adobe Font Metric (AFM) files from Macintosh and DOS
     filesystems available to Unix as SCSI disk devices.  The Adobe Font Folio
     CD-ROM for the Macintosh and 3.5" diskettes in either Apple HFS or DOS
     format may be used in this way, for example.

     If the input file contains a TrueType font instead of a PostScript font,
     the output will be a PostScript Type 42 font and not a conversion of the
     TrueType font to Type 1 or Type 3.  Therefore the PostScript interpreter
     must include a full TrueType rasterizer for the resulting font file to be
     usable.

     A series of operations may be specified on the command-line with the
     converted files being written to the current output file.  A new output
     file may be specified before each operation.  The files from successive
     operations will be concatenated on the output file if no new output file
     is specified between them.

     Files specified at the end of the command-line are examined to determine
     whether they are in Macintosh or IBM PC format and the appropriate
     conversion is applied.  If more than one file is specified at the end of
     the command-line, the output will be concatenated on the current output
     file.

     Consult the documentation for your Adobe POSTSCRIPT software for
     instructions on how to complete the installation of the converted font
     files.

OPTIONS
     -a fontname
          Copy the Adobe Font Metric (AFM) file for the specified font from
          the Macintosh filesystem (HFS) to the output file.  Either the
          POSTSCRIPT font name or the Macintosh font file name may be
          specified.  (i.e. StoneInformal-Italic is equivalent to
          StoneInfIta.)  The default HFS is the local CD-ROM reader.
     -d scsidevice
          Use the specified SCSI block device to access a Macintosh
          Hierarchical File System (HFS) or a DOS file system, depending on
          subsequent command line options.  The device may contain the Adobe
          Font Folio CD-ROM for the Macintosh or the printer font disk from a
          Macintosh or IBM PC font package, for example.  Consult your system
          documentation for the correct name of the SCSI device for the CD-ROM
          or diskette drive to be used.  Note that a Sun SPARCstation will
          only accept high density diskettes so the files from a Macintosh
          printer font disk would need to be copied to a high density diskette
          before they could be read on the workstation.

     -f fontname
          Convert the Macintosh-format printer font for the specified
          POSTSCRIPT font on the Font Folio and copy it to the output file.
          Either the POSTSCRIPT font name or the Macintosh font file name may
          be specified (see above).

     -i ibmfile
          Convert the IBM PC printer font from the specified file and copy it
          to the output file.  Use Binary format to transfer the font file to
          the Unix system from the printer font disk supplied in the Adobe
          font package.

     -l typename
          List files on the Font Folio which have the specified Macintosh file
          type.  The file type is specified as a string of up to four
          characters.  Although the formal Macintosh file type is a 32-bit
          integer, most file types have been chosen to be readable as four
          ASCII characters.  Ordinary text files have type "TEXT" and typeface
          programs have type "LWFN".  The null string ("") may be specified to
          list all files (but not directories) on the Font Folio.  Consult the
          Apple Macintosh technical documentation for further information on
          file types.

     -m macfile
          Convert a Macintosh printer font from the specified file and copy it
          to the output file.  Use MacBinary format to transfer the font file
          to the Unix system from the Printer Fonts folder on the disk
          supplied in the font package.

     -o outputfile
          Copy subsequently converted files and other output to the specified
          file.  This option may be repeated between the other conversion and
          list options to direct the results of different operations to
          separate files.  Output is directed to stdout by default.

     -t filename
          Copy the specified file of type "TEXT" from the Macintosh filesystem
          (HFS) to the output file. Note that no directory or folder can be
          specified in the filename.  The default HFS is the local CD-ROM
          reader.
     -A dosasciifile
          Copy the specified ASCII file from the DOS file system on the
          specified SCSI device to the output file, converting <cr><lf> line
          ending sequences to just <lf>.  The full path in the DOS file system
          must be specified.

     -B dosbinaryfile
          Copy the specified file verbatim from the DOS file system on the
          specified SCSI device to the output file.  The full path in the DOS
          file system must be specified.

     -F dosfontfile
          Convert an IBM PC printer font from the specified file in the DOS
          file system on the specified SCSI device and copy it to the output
          file. The actual filename is required because there is no
          algorithmic mapping between POSTSCRIPT font names and DOS filenames.
          (For the time being, the full path in the DOS file system must be
          specified.)

     -L   List the contents of the DOS filesystem on the specified SCSI
          device.

     -v   Print the unixfont version number.

EXAMPLE
     The following three commands are equivalent:

     $ unixfont StoneInfIta.Bin > font.ps
     $ unixfont -m StoneInfIta.Bin > font.ps
     $ unixfont -o font.ps -m StoneInfIta.Bin

     The following command converts the IBM PC printer font file for
     AvantGarde-DemiOblique:

     $ unixfont -o font.ps agdo____.pfb

     The following command extracts both the typeface program and the AFM file
     for the StoneInformal-Italic font from the Font Folio:

     $ unixfont -o font.ps -f StoneInformal-Italic -o font.afm -a StoneInfIta

     The following command extracts the typeface program for AvantGarde-
     DemiOblique from an IBM PC font package (DOS) diskette (the device
     /dev/fd0 is a Sun SPARCstation floppy drive):

     $ unixfont -d /dev/fd0 -o font.ps -F fonts\agdo____.pfb

BUGS
     Whenever an output file is specified, it is created regardless of the
     success of the subsequent operation(s).  This may leave a zero length new
     file or truncate an existing file to zero length.

     The Macintosh directory structure on the Font Folio is currently ignored
     (for program simplicity) and the B*-tree leaves are searched
     sequentially.  This means (a) that a file is assumed to be effectively
     unique (i.e. duplicate names are implicitly copies) and (b) file
     retrieval can be slow on slow filesystems because of the linear filename
     search.  However, accesses to the Font Folio are expected to be
     infrequent because typeface programs will need to be copied to the hard
     disk for more efficient use in any case.

     All errors terminate the program.

     unixfont currently cannot automatically identify PC format TrueType files
     stored in the Unix filesystem. (Use the -i command line option to force
     unixfont to treat the input file as a PC format font and it will
     determine automatically that it is a TrueType font instead of a Type 1
     font.) The -F option will work to read a TrueType font from a DOS
     filesystem diskette.

SEE ALSO
     POSTSCRIPT Language Reference Manual and POSTSCRIPT Language Supplement
     for your Adobe POSTSCRIPT interpreter.

AUTHOR
     Adobe Systems Incorporated

NOTES
     Typeface programs are licensed for use with individual POSTSCRIPT
     interpreters either in a printer or on a workstation.  To use a typeface
     program with multiple POSTSCRIPT interpreters, a multiple-printer license
     is required.  The unixfont program must be used exclusively to convert a
     licensed typeface program which is not directly available in Unix format
     into that format from the presently available Adobe typeface packages.
     The program must not be used to duplicate typeface programs for multiple
     uses in the absence of the appropriate license.

     POSTSCRIPT is a trademark of Adobe Systems Incorporated registered in
     certain jurisdictions.  Font Folio and TranScript are trademarks of Adobe
     Systems Incorporated.  Macintosh is a registered trademark of Apple
     Computer Incorporated.  IBM is a registered trademark of International
     Business Machines Incorporated.

     Copyright (c) 1989-1991, 1994 Adobe Systems Incorporated.  All rights
     reserved.